@@ -23,6 +23,8 @@
 #define ETIME ETIMEDOUT				/* For FreeBSD */
 #endif
 
+#include <my_atomic.h>
+
 #ifdef  __cplusplus
 #define EXTERNC extern "C"
 extern "C" {
@@ -803,6 +805,26 @@ extern uint thd_lib_detected;
 #define statistic_sub(V,C,L)     (V)-=(C)
 #endif /* SAFE_STATISTICS */
 
+static inline void thread_safe_increment32(int32 *value)
+{
+  (void) my_atomic_add32_explicit(value, 1, MY_MEMORY_ORDER_RELAXED);
+}
+
+static inline void thread_safe_decrement32(int32 *value)
+{
+  (void) my_atomic_add32_explicit(value, -1, MY_MEMORY_ORDER_RELAXED);
+}
+
+static inline void thread_safe_increment64(int64 *value)
+{
+  (void) my_atomic_add64_explicit(value, 1, MY_MEMORY_ORDER_RELAXED);
+}
+
+static inline void thread_safe_decrement64(int64 *value)
+{
+  (void) my_atomic_add64_explicit(value, -1, MY_MEMORY_ORDER_RELAXED);
+}
+
 /*
   No locking needed, the counter is owned by the thread
 */
